/**
 * Image2CSS Plugin
 *
 * Converts image into CSS box-shadow
 *
 * @category  WeBuilder Plugin
 * @package   Image2CSS
 * @author    Peter Klein <pmk@io.dk>
 * @copyright 2015
 * @license   http://www.freebsd.org/copyright/license.html  BSD License
 * @version   1.0
 */

/**
 * [CLASS/FUNCTION INDEX of SCRIPT]
 *
 *     41   function RenderForm(sender)
 *    120   function OnWebkitData(channel, data)
 *    134   function OnButtonClick(sender)
 *    144   function OnInstalled()
 *
 * TOTAL FUNCTIONS: 4
 * (This index is automatically created/updated by the WeBuilder plugin "DocBlock Comments")
 *
 */

/**
 * Global variables
 *
 * @var web, wkForm
 */
var web, wkForm;

/**
 * Render Modal form
 *
 * @param  TObject   sender
 *
 * @return void
 */
function RenderForm(sender) {
	if (Document.CurrentCodeType != ltCSS) {
		Alert("Works only inside CSS codeblocks or in CSS files.");
		return;
	}

	var wkMargin = 12, wkPanelBorderSize = 1;

  wkForm = new TForm(WeBuilder);
	wkForm.Width = 950;
	wkForm.Height = 590 + wkMargin;
  wkForm.Position = poScreenCenter;
  wkForm.Caption = "Image2CSS";
  wkForm.FormStyle = fsStayOnTop;
  wkForm.Font.Color = clWindowText;
  wkForm.Font.Height = -13;
  wkForm.Font.Name = "Tahoma";

	// Webkit panel
	var wkPanel = new TPanel(wkForm);
  wkPanel.Parent = wkForm;
	wkPanel.Align = alNone;//alClient;
	wkPanel.Anchors = akLeft + akTop + akRight + akBottom;
	wkPanel.SetBounds(wkMargin, wkMargin, wkForm.ClientWidth - (wkMargin * 2), wkForm.ClientHeight - wkMargin - 50);

	// ScriptableChromium object (placed inside Webkit panel)
  web = Script.CreateScriptableWebkit(wkPanel, Script.GetPath + "index.html", "");
  web.Subscribe("image2css", "OnWebkitData"); // System channel for recieving final data and close form
  web.Webkit.Parent = wkPanel;
  web.Webkit.Top = wkPanelBorderSize;
  web.Webkit.Left = wkPanelBorderSize;
  web.Webkit.Width = wkForm.ClientWidth - wkMargin * 2 - wkPanelBorderSize * 2;
  web.Webkit.Height = wkForm.ClientHeight - wkMargin - wkPanelBorderSize * 2 - 50;
  //web.Webkit.Anchors = akLeft || akRight || akTop || akBottom;
  web.Webkit.Align = alClient;

	var buttonWidth = 75, spacing = 10;

	// Button panel
	var btnPanel = new TPanel(wkForm);
  btnPanel.Parent = wkForm;
	btnPanel.Align = alNone;
	btnPanel.BevelOuter = bvNone;
	btnPanel.Anchors = akBottom;// + akRight;
	btnPanel.SetBounds(Trunc((wkForm.ClientWidth - (buttonWidth * 2 + spacing))/2), web.Webkit.Height + wkMargin + wkPanelBorderSize * 2, buttonWidth * 2 + spacing, 50 - wkPanelBorderSize * 2);

	// Ok button object (placed inside Button panel)
  var wbOk = new TButton(wkForm);
  wbOk.Parent = btnPanel;
	wbOk.Anchors = akTop;
  wbOk.Caption = "Ok";
  wbOk.Default = true;
	wbOk.ModalResult = mrNone;
  wbOk.OnClick = "OnButtonClick";
  wbOk.SetBounds(0, 12, buttonWidth, 25);

	// Close button object (placed inside Button panel)
  var wbClose = new TButton(wkForm);
  wbClose.Parent = btnPanel;
	wbClose.Anchors = akTop;
  wbClose.Caption = "Close";
	wbClose.ModalResult = mrCancel;
  wbClose.SetBounds(buttonWidth + spacing, 12, buttonWidth, 25);

	wkForm.ShowModal;

	delete web;
	delete wkForm; // Remove progressForm object

}

/**
 * Recieves system data from webkit html page
 *
 * @param  string   channel
 * @param  mixed   data
 *
 * @return string
 */
function OnWebkitData(channel, data) {
	Editor.SelText = data;
	wkForm.ModalResult = mrOk; 	// Trigger modalform closing
	return;
}

/**
 * Callback function for button on WeBuilder part of form.
 * Sends signal back to Webkit part of form
 *
 * @param  TButton   sender
 *
 * @return void
 */
function OnButtonClick(sender) {
	// Signal Webkit to send return data
  web.Send("close", "");
}

/**
 * Show info when plugin is installed
 *
 * @return void
 */
function OnInstalled() {
  alert("Image2CSS 1.0 by Peter Klein installed sucessfully!");
}

Script.ConnectSignal("installed", "OnInstalled");
Script.RegisterDocumentAction("", "Image2CSS", "", "RenderForm");
